Logical Graph Editor
Description: Interactive flowchart diagram implemented by GoJS in JavaScript for HTML.

Palette

- Graph
- JSON
- PNG
- Translate

| Translate the Logical Graph to either Physical Graph Template (PGT) or Physical Graph Template Partition (PGTP)
Algorithm 0 |
# of Islands |
Algorithm 1 | Minimise data movement while subject to load balancing
# of nodes |
Partition label |
Load balancing | %
Algorithm 2 | Minimise execution time while subject to each partition's DoP
Partition label |
Max DoP per partition | (DoP - Degree of Parallelism)
Lookahead Algorithm | Minimise # of Partitions while subject to completion deadline
Deadline (time unit) |
Greediness of deadline pursue | %
Partition label |
Max DoP per partition | (DoP - Degree of Parallelism)
Algorithm 4 | Minimise # of Partitions while (optionally) subject to completion deadline
| WARNING - PSO is 10x slower, a larger Swarm size or Dimension makes it even slower!
Swarm size |
Dimension of search space |
Deadline (time unit) |
Partition label |
Max DoP per partition | (DoP - Degree of Parallelism)

Logical Graphs

Mouse-over a Node to view its ports. Drag from these ports to create new Links. Selecting a Node and then clicking its TextBlock will allow you to edit text (except on the Start and End Nodes).
Any issues please email chen DOT wu AT icrar DOT org